notebook: Jupyter notebook, a web-based notebook environment for interactive computing
======================================================================================

Description
-----------

The Jupyter HTML notebook is a web-based notebook environment for
interactive computing.

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/notebook/
